@@ -13,9 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from __future__ import print_function
-
 from oslo_config import cfg
+from oslo_config import types
 
 service_option = cfg.BoolOpt("manila",
                              default=True,
@@ -28,9 +27,11 @@ ShareGroup = [
     cfg.StrOpt("min_api_microversion",
                default="2.0",
                help="The minimum api microversion is configured to be the "
-                    "value of the minimum microversion supported by Manila."),
+                    "value of the minimum microversion supported by Manila. "
+                    "This value is only used to validate the versions "
+                    "response from Manila."),
     cfg.StrOpt("max_api_microversion",
-               default="2.55",
+               default="2.65",
                help="The maximum api microversion is configured to be the "
                     "value of the latest microversion supported by Manila."),
     cfg.StrOpt("region",
@@ -130,6 +131,16 @@ ShareGroup = [
                help="Backend capability to create consistent snapshots of "
                     "share group members. Will be used with creation "
                     "of new share group types as group spec."),
+    cfg.BoolOpt("capability_thin_provisioned",
+                default=False,
+                help="Defines whether to create shares as thin provisioned, "
+                     "adding the extra spec 'thin_provisioning' as 'True' for "
+                     "setting up the custom share types. It may be useful to "
+                     "run tempest with  back end storage systems without much "
+                     "space. Take care enabling it, the manila scheduler "
+                     "capability filter will request this capability in all "
+                     "share types and the the capacity filter will allow "
+                     "oversubscription."),
     cfg.StrOpt("share_network_id",
                default="",
                help="Some backend drivers requires share network "
@@ -176,6 +187,24 @@ ShareGroup = [
                 help="Whether to suppress errors with clean up operation "
                      "or not. There are cases when we may want to skip "
                      "such errors and catch only test errors."),
+    cfg.MultiOpt("security_service",
+                 item_type=types.Dict(),
+                 secret=True,
+                 help="This option enables specifying security service "
+                      "parameters needed to create security services "
+                      "dynamically in order to run the tempest tests. "
+                      "The configured security service must be reachable by "
+                      "the project share networks created by the tests. So, "
+                      "ideally project networks must be able to route to the "
+                      "network where the pre-existing security services has "
+                      "been deployed. The set of parameters that can be "
+                      "configured is the same used in the security service "
+                      "creation. You can repeat this option many times, and "
+                      "each entry takes the standard dict config parameters: "
+                      "security_service = "
+                      "ss_type:<ldap, kerberos or active_directory>, "
+                      "ss_dns_ip:value, ss_user:value, ss_password=value, "
+                      "ss_domain:value, ss_server:value"),
 
     # Switching ON/OFF test suites filtered by features
     cfg.BoolOpt("run_quota_tests",
@@ -245,6 +274,10 @@ ShareGroup = [
                 help="Defines whether to run tests that create share from "
                      "snapshots in another pool or az. Enable this "
                      "option if the used driver supports it."),
+    cfg.BoolOpt("run_share_server_migration_tests",
+                default=False,
+                help="Defines whether to run share servers migration tests. "
+                     "Enable this option if the used driver supports it."),
 
     cfg.StrOpt("image_with_share_tools",
                default="manila-service-image-master",
@@ -262,6 +295,10 @@ ShareGroup = [
                default=1500,
                help="Time to wait for share migration before "
                     "timing out (seconds)."),
+    cfg.IntOpt("share_server_migration_timeout",
+               default="1500",
+               help="Time to wait for share server migration before "
+                    "timing out (seconds)."),
     cfg.StrOpt("default_share_type_name",
                help="Default share type name to use in tempest tests."),
     cfg.StrOpt("backend_replication_type",
@@ -273,6 +310,11 @@ ShareGroup = [
                help="Default size in GB for shares created by share tests."),
     cfg.BoolOpt("run_ipv6_tests",
                 default=False,
-                help="Enable or disable running IPv6 tests."),
-
+                help="Enable or disable running IPv6 NFS scenario tests. "
+                     "These tests validate that IPv6 export locations work, "
+                     "and that access can be provided to IPv6 clients. When "
+                     "you do not specify a storage_network, the tests will "
+                     "attempt to create an IPv6 subnet on the project network "
+                     "they create for ping and SSH to the client test VM "
+                     "where data path testing is performed."),
 ]
