@@ -76,12 +76,13 @@ class SharesClient(rest_client.RestClient):
         body = json.dumps(post_body)
         resp, body = self.post("shares", body)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def delete_share(self, share_id):
         resp, body = self.delete("shares/%s" % share_id)
         self.expected_success(202, resp.status)
-        return body
+        return rest_client.ResponseBody(resp, body)
 
     def manage_share(self, service_host, protocol, export_path,
                      share_type_id, name=None, description=None):
@@ -98,13 +99,14 @@ class SharesClient(rest_client.RestClient):
         body = json.dumps(post_body)
         resp, body = self.post("os-share-manage", body)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def unmanage_share(self, share_id):
         resp, body = self.post(
             "os-share-unmanage/%s/unmanage" % share_id, None)
         self.expected_success(202, resp.status)
-        return body
+        return rest_client.ResponseBody(resp, body)
 
     def list_shares(self, detailed=False, params=None):
         """Get list of shares w/o filters."""
@@ -112,7 +114,8 @@ class SharesClient(rest_client.RestClient):
         uri += '?%s' % urlparse.urlencode(params) if params else ''
         resp, body = self.get(uri)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def list_shares_with_detail(self, params=None):
         """Get detailed list of shares w/o filters."""
@@ -121,7 +124,8 @@ class SharesClient(rest_client.RestClient):
     def get_share(self, share_id):
         resp, body = self.get("shares/%s" % share_id)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def create_access_rule(self, share_id, access_type="ip",
                            access_to="0.0.0.0", access_level=None):
@@ -135,13 +139,15 @@ class SharesClient(rest_client.RestClient):
         body = json.dumps(post_body)
         resp, body = self.post("shares/%s/action" % share_id, body)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def list_access_rules(self, share_id):
         body = {"os-access_list": None}
         resp, body = self.post("shares/%s/action" % share_id, json.dumps(body))
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def delete_access_rule(self, share_id, rule_id):
         post_body = {
@@ -152,7 +158,7 @@ class SharesClient(rest_client.RestClient):
         body = json.dumps(post_body)
         resp, body = self.post("shares/%s/action" % share_id, body)
         self.expected_success(202, resp.status)
-        return body
+        return rest_client.ResponseBody(resp, body)
 
     def extend_share(self, share_id, new_size):
         post_body = {
@@ -163,7 +169,7 @@ class SharesClient(rest_client.RestClient):
         body = json.dumps(post_body)
         resp, body = self.post("shares/%s/action" % share_id, body)
         self.expected_success(202, resp.status)
-        return body
+        return rest_client.ResponseBody(resp, body)
 
     def shrink_share(self, share_id, new_size):
         post_body = {
@@ -174,7 +180,7 @@ class SharesClient(rest_client.RestClient):
         body = json.dumps(post_body)
         resp, body = self.post("shares/%s/action" % share_id, body)
         self.expected_success(202, resp.status)
-        return body
+        return rest_client.ResponseBody(resp, body)
 
     def create_snapshot(self, share_id, name=None, description=None,
                         force=False):
@@ -194,12 +200,14 @@ class SharesClient(rest_client.RestClient):
         body = json.dumps(post_body)
         resp, body = self.post("snapshots", body)
         self.expected_success(202, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def get_snapshot(self, snapshot_id):
         resp, body = self.get("snapshots/%s" % snapshot_id)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def list_snapshots(self, detailed=False, params=None):
         """Get list of share snapshots w/o filters."""
@@ -207,7 +215,8 @@ class SharesClient(rest_client.RestClient):
         uri += '?%s' % urlparse.urlencode(params) if params else ''
         resp, body = self.get(uri)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def list_snapshots_with_detail(self, params=None):
         """Get detailed list of share snapshots w/o filters."""
@@ -216,78 +225,13 @@ class SharesClient(rest_client.RestClient):
     def delete_snapshot(self, snap_id):
         resp, body = self.delete("snapshots/%s" % snap_id)
         self.expected_success(202, resp.status)
-        return body
-
-    def wait_for_share_status(self, share_id, status):
-        """Waits for a share to reach a given status."""
-        body = self.get_share(share_id)
-        share_name = body['name']
-        share_status = body['status']
-        start = int(time.time())
-
-        while share_status != status:
-            time.sleep(self.build_interval)
-            body = self.get_share(share_id)
-            share_status = body['status']
-            if share_status == status:
-                return
-            elif 'error' in share_status.lower():
-                raise share_exceptions.ShareBuildErrorException(
-                    share_id=share_id)
-
-            if int(time.time()) - start >= self.build_timeout:
-                message = ('Share %s failed to reach %s status within '
-                           'the required time (%s s).' %
-                           (share_name, status, self.build_timeout))
-                raise exceptions.TimeoutException(message)
-
-    def wait_for_snapshot_status(self, snapshot_id, status):
-        """Waits for a snapshot to reach a given status."""
-        body = self.get_snapshot(snapshot_id)
-        snapshot_name = body['name']
-        snapshot_status = body['status']
-        start = int(time.time())
-
-        while snapshot_status != status:
-            time.sleep(self.build_interval)
-            body = self.get_snapshot(snapshot_id)
-            snapshot_status = body['status']
-            if 'error' in snapshot_status:
-                raise share_exceptions.SnapshotBuildErrorException(
-                    snapshot_id=snapshot_id)
-
-            if int(time.time()) - start >= self.build_timeout:
-                message = ('Share Snapshot %s failed to reach %s status '
-                           'within the required time (%s s).' %
-                           (snapshot_name, status, self.build_timeout))
-                raise exceptions.TimeoutException(message)
-
-    def wait_for_access_rule_status(self, share_id, rule_id, status,
-                                    raise_rule_in_error_state=True):
-        """Waits for an access rule to reach a given status."""
-        rule_status = "new"
-        start = int(time.time())
-        while rule_status != status:
-            time.sleep(self.build_interval)
-            rules = self.list_access_rules(share_id)
-            for rule in rules:
-                if rule["id"] in rule_id:
-                    rule_status = rule['state']
-                    break
-            if 'error' in rule_status and raise_rule_in_error_state:
-                raise share_exceptions.AccessRuleBuildErrorException(
-                    rule_id=rule_id)
-
-            if int(time.time()) - start >= self.build_timeout:
-                message = ('Share Access Rule %s failed to reach %s status '
-                           'within the required time (%s s).' %
-                           (rule_id, status, self.build_timeout))
-                raise exceptions.TimeoutException(message)
+        return rest_client.ResponseBody(resp, body)
 
     def default_quotas(self, tenant_id):
         resp, body = self.get("os-quota-sets/%s/defaults" % tenant_id)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def show_quotas(self, tenant_id, user_id=None):
         uri = "os-quota-sets/%s" % tenant_id
@@ -295,7 +239,8 @@ class SharesClient(rest_client.RestClient):
             uri += "?user_id=%s" % user_id
         resp, body = self.get(uri)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def reset_quotas(self, tenant_id, user_id=None):
         uri = "os-quota-sets/%s" % tenant_id
@@ -303,7 +248,7 @@ class SharesClient(rest_client.RestClient):
             uri += "?user_id=%s" % user_id
         resp, body = self.delete(uri)
         self.expected_success(202, resp.status)
-        return body
+        return rest_client.ResponseBody(resp, body)
 
     def update_quotas(self, tenant_id, user_id=None, shares=None,
                       snapshots=None, gigabytes=None, snapshot_gigabytes=None,
@@ -329,12 +274,14 @@ class SharesClient(rest_client.RestClient):
 
         resp, body = self.put(uri, put_body)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def get_limits(self):
         resp, body = self.get("limits")
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def is_resource_deleted(self, *args, **kwargs):
         """Verifies whether provided resource deleted or not.
@@ -347,7 +294,7 @@ class SharesClient(rest_client.RestClient):
             if "rule_id" in kwargs:
                 rule_id = kwargs.get("rule_id")
                 share_id = kwargs.get("share_id")
-                rules = self.list_access_rules(share_id)
+                rules = self.list_access_rules(share_id)['access_list']
                 for rule in rules:
                     if rule["id"] == rule_id:
                         return False
@@ -400,9 +347,10 @@ class SharesClient(rest_client.RestClient):
             time.sleep(self.build_interval)
 
     def list_extensions(self):
-        resp, extensions = self.get("extensions")
+        resp, body = self.get("extensions")
         self.expected_success(200, resp.status)
-        return self._parse_resp(extensions)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def update_share(self, share_id, name=None, desc=None, is_public=None):
         body = {"share": {}}
@@ -415,7 +363,8 @@ class SharesClient(rest_client.RestClient):
         body = json.dumps(body)
         resp, body = self.put("shares/%s" % share_id, body)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def rename_snapshot(self, snapshot_id, name, desc=None):
         body = {"snapshot": {"display_name": name}}
@@ -424,7 +373,8 @@ class SharesClient(rest_client.RestClient):
         body = json.dumps(body)
         resp, body = self.put("snapshots/%s" % snapshot_id, body)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def reset_state(self, s_id, status="error", s_type="shares"):
         """Resets the state of a share or a snapshot.
@@ -436,7 +386,7 @@ class SharesClient(rest_client.RestClient):
         body = json.dumps(body)
         resp, body = self.post("%s/%s/action" % (s_type, s_id), body)
         self.expected_success(202, resp.status)
-        return body
+        return rest_client.ResponseBody(resp, body)
 
     def force_delete(self, s_id, s_type="shares"):
         """Force delete share or snapshot.
@@ -447,7 +397,7 @@ class SharesClient(rest_client.RestClient):
         body = json.dumps(body)
         resp, body = self.post("%s/%s/action" % (s_type, s_id), body)
         self.expected_success(202, resp.status)
-        return body
+        return rest_client.ResponseBody(resp, body)
 
 ###############
 
@@ -458,7 +408,8 @@ class SharesClient(rest_client.RestClient):
             uri += '?%s' % urlparse.urlencode(params)
         resp, body = self.get(uri)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
 ###############
 
@@ -469,11 +420,12 @@ class SharesClient(rest_client.RestClient):
         post_body = {"metadata": metadata}
         body = json.dumps(post_body)
         if method == "post":
-            resp, metadata = self.post(uri, body)
+            resp, body = self.post(uri, body)
         if method == "put":
-            resp, metadata = self.put(uri, body)
+            resp, body = self.put(uri, body)
         self.expected_success(200, resp.status)
-        return self._parse_resp(metadata)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def set_metadata(self, share_id, metadata=None):
         return self._update_metadata(share_id, metadata)
@@ -484,11 +436,17 @@ class SharesClient(rest_client.RestClient):
     def delete_metadata(self, share_id, key):
         resp, body = self.delete("shares/%s/metadata/%s" % (share_id, key))
         self.expected_success(200, resp.status)
-        return body
+        return rest_client.ResponseBody(resp, body)
 
     def get_metadata(self, share_id):
         resp, body = self.get("shares/%s/metadata" % share_id)
         self.expected_success(200, resp.status)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
+
+    def get_metadata_item(self, share_id, key):
+        resp, body = self.get("shares/%s/metadata/%s" % (share_id, key))
+        self.expected_success(200, resp.status)
         return self._parse_resp(body)
 
 ###############
@@ -501,7 +459,8 @@ class SharesClient(rest_client.RestClient):
         body = json.dumps({"security_service": post_body})
         resp, body = self.post("security-services", body)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def update_security_service(self, ss_id, **kwargs):
         # ss_id - id of security-service entity
@@ -511,12 +470,14 @@ class SharesClient(rest_client.RestClient):
         body = json.dumps({"security_service": kwargs})
         resp, body = self.put("security-services/%s" % ss_id, body)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def get_security_service(self, ss_id):
         resp, body = self.get("security-services/%s" % ss_id)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def list_security_services(self, detailed=False, params=None):
         uri = "security-services"
@@ -526,12 +487,13 @@ class SharesClient(rest_client.RestClient):
             uri += "?%s" % urlparse.urlencode(params)
         resp, body = self.get(uri)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def delete_security_service(self, ss_id):
         resp, body = self.delete("security-services/%s" % ss_id)
         self.expected_success(202, resp.status)
-        return body
+        return rest_client.ResponseBody(resp, body)
 
 ###############
 
@@ -541,7 +503,8 @@ class SharesClient(rest_client.RestClient):
         body = json.dumps({"share_network": kwargs})
         resp, body = self.post("share-networks", body)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def update_share_network(self, sn_id, **kwargs):
         # kwargs: name, description
@@ -549,17 +512,20 @@ class SharesClient(rest_client.RestClient):
         body = json.dumps({"share_network": kwargs})
         resp, body = self.put("share-networks/%s" % sn_id, body)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def get_share_network(self, sn_id):
         resp, body = self.get("share-networks/%s" % sn_id)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def list_share_networks(self):
         resp, body = self.get("share-networks")
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def list_share_networks_with_detail(self, params=None):
         """List the details of all shares."""
@@ -568,12 +534,13 @@ class SharesClient(rest_client.RestClient):
             uri += "?%s" % urlparse.urlencode(params)
         resp, body = self.get(uri)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def delete_share_network(self, sn_id):
         resp, body = self.delete("share-networks/%s" % sn_id)
         self.expected_success(202, resp.status)
-        return body
+        return rest_client.ResponseBody(resp, body)
 
 ###############
 
@@ -590,21 +557,21 @@ class SharesClient(rest_client.RestClient):
         body = json.dumps(data)
         resp, body = self.post("share-networks/%s/action" % sn_id, body)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def add_sec_service_to_share_network(self, sn_id, ss_id):
-        body = self._map_security_service_and_share_network(sn_id, ss_id)
-        return body
+        return self._map_security_service_and_share_network(sn_id, ss_id)
 
     def remove_sec_service_from_share_network(self, sn_id, ss_id):
-        body = self._map_security_service_and_share_network(
+        return self._map_security_service_and_share_network(
             sn_id, ss_id, "remove")
-        return body
 
     def list_sec_services_for_share_network(self, sn_id):
         resp, body = self.get("security-services?share_network_id=%s" % sn_id)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
 ###############
 
@@ -614,7 +581,8 @@ class SharesClient(rest_client.RestClient):
             uri += '?%s' % urlparse.urlencode(params)
         resp, body = self.get(uri)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def create_share_type(self, name, is_public=True, **kwargs):
         post_body = {
@@ -625,17 +593,25 @@ class SharesClient(rest_client.RestClient):
         post_body = json.dumps({'share_type': post_body})
         resp, body = self.post('types', post_body)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def delete_share_type(self, share_type_id):
         resp, body = self.delete("types/%s" % share_type_id)
         self.expected_success(202, resp.status)
-        return body
+        return rest_client.ResponseBody(resp, body)
 
     def get_share_type(self, share_type_id):
         resp, body = self.get("types/%s" % share_type_id)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
+
+    def get_default_share_type(self):
+        resp, body = self.get("types/default")
+        self.expected_success(200, resp.status)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def add_access_to_share_type(self, share_type_id, project_id):
         uri = 'types/%s/action' % share_type_id
@@ -643,7 +619,7 @@ class SharesClient(rest_client.RestClient):
         post_body = json.dumps({'addProjectAccess': post_body})
         resp, body = self.post(uri, post_body)
         self.expected_success(202, resp.status)
-        return body
+        return rest_client.ResponseBody(resp, body)
 
     def remove_access_from_share_type(self, share_type_id, project_id):
         uri = 'types/%s/action' % share_type_id
@@ -651,14 +627,15 @@ class SharesClient(rest_client.RestClient):
         post_body = json.dumps({'removeProjectAccess': post_body})
         resp, body = self.post(uri, post_body)
         self.expected_success(202, resp.status)
-        return body
+        return rest_client.ResponseBody(resp, body)
 
     def list_access_to_share_type(self, share_type_id):
         uri = 'types/%s/os-share-type-access' % share_type_id
         resp, body = self.get(uri)
         # [{"share_type_id": "%st_id%", "project_id": "%project_id%"}, ]
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
 ###############
 
@@ -667,13 +644,15 @@ class SharesClient(rest_client.RestClient):
         post_body = json.dumps({'extra_specs': extra_specs})
         resp, body = self.post(url, post_body)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def get_share_type_extra_spec(self, share_type_id, extra_spec_name):
         uri = "types/%s/extra_specs/%s" % (share_type_id, extra_spec_name)
         resp, body = self.get(uri)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def get_share_type_extra_specs(self, share_type_id, params=None):
         uri = "types/%s/extra_specs" % share_type_id
@@ -681,7 +660,8 @@ class SharesClient(rest_client.RestClient):
             uri += '?%s' % urlparse.urlencode(params)
         resp, body = self.get(uri)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def update_share_type_extra_spec(self, share_type_id, spec_name,
                                      spec_value):
@@ -690,7 +670,8 @@ class SharesClient(rest_client.RestClient):
         post_body = json.dumps(extra_spec)
         resp, body = self.put(uri, post_body)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def update_share_type_extra_specs(self, share_type_id, extra_specs):
         uri = "types/%s/extra_specs" % share_type_id
@@ -698,13 +679,14 @@ class SharesClient(rest_client.RestClient):
         post_body = json.dumps(extra_specs)
         resp, body = self.post(uri, post_body)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def delete_share_type_extra_spec(self, share_type_id, extra_spec_name):
         uri = "types/%s/extra_specs/%s" % (share_type_id, extra_spec_name)
         resp, body = self.delete(uri)
         self.expected_success(202, resp.status)
-        return body
+        return rest_client.ResponseBody(resp, body)
 
 ###############
 
@@ -715,28 +697,31 @@ class SharesClient(rest_client.RestClient):
             uri += "?%s" % urlparse.urlencode(search_opts)
         resp, body = self.get(uri)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def delete_share_server(self, share_server_id):
         """Delete share server by its ID."""
         uri = "share-servers/%s" % share_server_id
         resp, body = self.delete(uri)
         self.expected_success(202, resp.status)
-        return body
+        return rest_client.ResponseBody(resp, body)
 
     def show_share_server(self, share_server_id):
         """Get share server info."""
         uri = "share-servers/%s" % share_server_id
         resp, body = self.get(uri)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
     def show_share_server_details(self, share_server_id):
         """Get share server details only."""
         uri = "share-servers/%s/details" % share_server_id
         resp, body = self.get(uri)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
 ###############
 
@@ -749,7 +734,8 @@ class SharesClient(rest_client.RestClient):
             uri += "?%s" % urlparse.urlencode(search_opts)
         resp, body = self.get(uri)
         self.expected_success(200, resp.status)
-        return json.loads(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
 
 ###############
 
@@ -758,4 +744,5 @@ class SharesClient(rest_client.RestClient):
         uri = 'os-availability-zone'
         resp, body = self.get(uri)
         self.expected_success(200, resp.status)
-        return self._parse_resp(body)
+        body = json.loads(body)
+        return rest_client.ResponseBody(resp, body)
