@@ -27,6 +27,7 @@ from tempest import test
 
 from manila_tempest_tests import clients
 from manila_tempest_tests.common import constants
+from manila_tempest_tests.common import waiters
 from manila_tempest_tests import share_exceptions
 from manila_tempest_tests import utils
 
@@ -93,10 +94,6 @@ class handle_cleanup_exceptions(object):
         return True  # Suppress error if any
 
 
-skip_if_microversion_not_supported = utils.skip_if_microversion_not_supported
-skip_if_microversion_lt = utils.skip_if_microversion_lt
-
-
 class BaseSharesTest(test.BaseTestCase):
     """Base test case class for all Manila API tests."""
 
@@ -114,18 +111,6 @@ class BaseSharesTest(test.BaseTestCase):
     # a stable class is used, which includes plugin registered services as well
     client_manager = clients.Clients
 
-    def skip_if_microversion_not_supported(self, microversion):
-        if not utils.is_microversion_supported(microversion):
-            raise self.skipException(
-                "Microversion '%s' is not supported." % microversion)
-
-    def skip_if_microversion_lt(self, microversion):
-        if utils.is_microversion_lt(CONF.share.max_api_microversion,
-                                    microversion):
-            raise self.skipException(
-                "Microversion must be greater than or equal to '%s'." %
-                microversion)
-
     @classmethod
     def skip_checks(cls):
         super(BaseSharesTest, cls).skip_checks()
@@ -376,7 +361,7 @@ class BaseSharesTest(test.BaseTestCase):
         if share_group_id:
             kwargs['share_group_id'] = share_group_id
 
-        share = client.create_share(**kwargs)
+        share = client.create_share(**kwargs)['share']
         resource = {"type": "share", "id": share["id"], "client": client,
                     "share_group_id": share_group_id}
         cleanup_list = (cls.class_resources if cleanup_in_class else
@@ -399,24 +384,24 @@ class BaseSharesTest(test.BaseTestCase):
             nondisruptive=nondisruptive, preserve_snapshots=preserve_snapshots,
             new_share_network_id=new_share_network_id,
             new_share_type_id=new_share_type_id, **kwargs)
-        share = client.wait_for_migration_status(
-            share_id, dest_host, wait_for_status, **kwargs)
+        share = waiters.wait_for_migration_status(
+            client, share_id, dest_host, wait_for_status, **kwargs)
         return share
 
     @classmethod
     def migration_complete(cls, share_id, dest_host, client=None, **kwargs):
         client = client or cls.shares_v2_client
         client.migration_complete(share_id, **kwargs)
-        share = client.wait_for_migration_status(
-            share_id, dest_host, 'migration_success', **kwargs)
+        share = waiters.wait_for_migration_status(
+            client, share_id, dest_host, 'migration_success', **kwargs)
         return share
 
     @classmethod
     def migration_cancel(cls, share_id, dest_host, client=None, **kwargs):
         client = client or cls.shares_v2_client
         client.migration_cancel(share_id, **kwargs)
-        share = client.wait_for_migration_status(
-            share_id, dest_host, 'migration_cancelled', **kwargs)
+        share = waiters.wait_for_migration_status(
+            client, share_id, dest_host, 'migration_cancelled', **kwargs)
         return share
 
     @classmethod
@@ -480,7 +465,8 @@ class BaseSharesTest(test.BaseTestCase):
                 client = d["kwargs"]["client"]
                 share_id = d["share"]["id"]
                 try:
-                    client.wait_for_share_status(share_id, "available")
+                    waiters.wait_for_resource_status(
+                        client, share_id, "available")
                     d["available"] = True
                 except (share_exceptions.ShareBuildErrorException,
                         exceptions.TimeoutException) as e:
@@ -513,7 +499,7 @@ class BaseSharesTest(test.BaseTestCase):
         if kwargs.get('source_share_group_snapshot_id') is None:
             kwargs['share_network_id'] = (share_network_id or
                                           client.share_network_id or None)
-        share_group = client.create_share_group(**kwargs)
+        share_group = client.create_share_group(**kwargs)['share_group']
         resource = {
             "type": "share_group",
             "id": share_group["id"],
@@ -527,7 +513,7 @@ class BaseSharesTest(test.BaseTestCase):
         if kwargs.get('source_share_group_snapshot_id'):
             new_share_group_shares = client.list_shares(
                 detailed=True,
-                params={'share_group_id': share_group['id']})
+                params={'share_group_id': share_group['id']})['shares']
 
             for share in new_share_group_shares:
                 resource = {"type": "share",
@@ -539,7 +525,9 @@ class BaseSharesTest(test.BaseTestCase):
                 else:
                     cls.method_resources.insert(0, resource)
 
-        client.wait_for_share_group_status(share_group['id'], 'available')
+        waiters.wait_for_resource_status(
+            client, share_group['id'], 'available',
+            resource_name='share_group')
         return share_group
 
     @classmethod
@@ -558,7 +546,7 @@ class BaseSharesTest(test.BaseTestCase):
             share_types=share_types,
             is_public=is_public,
             group_specs=group_specs,
-            **kwargs)
+            **kwargs)['share_group_type']
         resource = {
             "type": "share_group_type",
             "id": share_group_type["id"],
@@ -578,7 +566,8 @@ class BaseSharesTest(test.BaseTestCase):
             client = cls.shares_v2_client
         if description is None:
             description = "Tempest's snapshot"
-        snapshot = client.create_snapshot(share_id, name, description, force)
+        snapshot = client.create_snapshot(
+            share_id, name, description, force)['snapshot']
         resource = {
             "type": "snapshot",
             "id": snapshot["id"],
@@ -588,7 +577,8 @@ class BaseSharesTest(test.BaseTestCase):
             cls.class_resources.insert(0, resource)
         else:
             cls.method_resources.insert(0, resource)
-        client.wait_for_snapshot_status(snapshot["id"], "available")
+        waiters.wait_for_resource_status(client, snapshot["id"], "available",
+                                         resource_name='snapshot')
         return snapshot
 
     @classmethod
@@ -599,7 +589,8 @@ class BaseSharesTest(test.BaseTestCase):
         if description is None:
             description = "Tempest's share group snapshot"
         sg_snapshot = client.create_share_group_snapshot(
-            share_group_id, name=name, description=description, **kwargs)
+            share_group_id, name=name, description=description,
+            **kwargs)['share_group_snapshot']
         resource = {
             "type": "share_group_snapshot",
             "id": sg_snapshot["id"],
@@ -609,8 +600,9 @@ class BaseSharesTest(test.BaseTestCase):
             cls.class_resources.insert(0, resource)
         else:
             cls.method_resources.insert(0, resource)
-        client.wait_for_share_group_snapshot_status(
-            sg_snapshot["id"], "available")
+        waiters.wait_for_resource_status(
+            client, sg_snapshot["id"], "available",
+            resource_name="share_group_snapshot")
         return sg_snapshot
 
     @classmethod
@@ -624,7 +616,7 @@ class BaseSharesTest(test.BaseTestCase):
             '|'.join(['^%s$' % backend for backend in backends])
             if backends else '.*'
         )
-        cls.services = client.list_services()
+        cls.services = client.list_services()['services']
         zones = [service['zone'] for service in cls.services if
                  service['binary'] == 'manila-share' and
                  service['state'] == 'up' and
@@ -669,7 +661,7 @@ class BaseSharesTest(test.BaseTestCase):
         # Get the list of pools for the replication domain
         pools = self.admin_client.list_pools(detail=True)['pools']
         instance_host = self.admin_client.get_share(
-            self.shares[0]['id'])['host']
+            self.shares[0]['id'])['share']['host']
         host_pool = [p for p in pools if p['name'] == instance_host][0]
         rep_domain = host_pool['capabilities']['replication_domain']
         pools_in_rep_domain = [p for p in pools if p['capabilities'][
@@ -683,7 +675,8 @@ class BaseSharesTest(test.BaseTestCase):
                              version=CONF.share.max_api_microversion):
         client = client or cls.shares_v2_client
         replica = client.create_share_replica(
-            share_id, availability_zone=availability_zone, version=version)
+            share_id, availability_zone=availability_zone,
+            version=version)['share_replica']
         resource = {
             "type": "share_replica",
             "id": replica["id"],
@@ -696,8 +689,9 @@ class BaseSharesTest(test.BaseTestCase):
                 cls.class_resources.insert(0, resource)
             else:
                 cls.method_resources.insert(0, resource)
-        client.wait_for_share_replica_status(
-            replica["id"], constants.STATUS_AVAILABLE)
+        waiters.wait_for_resource_status(
+            client, replica["id"], constants.STATUS_AVAILABLE,
+            resource_name='share_replica')
         return replica
 
     @classmethod
@@ -714,11 +708,11 @@ class BaseSharesTest(test.BaseTestCase):
     def promote_share_replica(cls, replica_id, client=None,
                               version=CONF.share.max_api_microversion):
         client = client or cls.shares_v2_client
-        replica = client.promote_share_replica(replica_id, version=version)
-        client.wait_for_share_replica_status(
-            replica["id"],
-            constants.REPLICATION_STATE_ACTIVE,
-            status_attr="replica_state")
+        replica = client.promote_share_replica(
+            replica_id, version=version)['share_replica']
+        waiters.wait_for_resource_status(
+            client, replica["id"], constants.REPLICATION_STATE_ACTIVE,
+            resource_name='share_replica', status_attr="replica_state")
         return replica
 
     @classmethod
@@ -757,7 +751,7 @@ class BaseSharesTest(test.BaseTestCase):
 
         if client is None:
             client = cls.shares_client
-        share_network = client.create_share_network(**kwargs)
+        share_network = client.create_share_network(**kwargs)['share_network']
         resource = {
             "type": "share_network",
             "id": share_network["id"],
@@ -782,7 +776,8 @@ class BaseSharesTest(test.BaseTestCase):
                                     **kwargs):
         if client is None:
             client = cls.shares_v2_client
-        share_network_subnet = client.create_subnet(**kwargs)
+        share_network_subnet = client.create_subnet(
+            **kwargs)['share_network_subnet']
         resource = {
             "type": "share-network-subnet",
             "id": share_network_subnet["id"],
@@ -802,7 +797,8 @@ class BaseSharesTest(test.BaseTestCase):
                                 cleanup_in_class=False, **kwargs):
         if client is None:
             client = cls.shares_client
-        security_service = client.create_security_service(ss_type, **kwargs)
+        security_service = client.create_security_service(
+            ss_type, **kwargs)['security_service']
         resource = {
             "type": "security_service",
             "id": security_service["id"],
@@ -814,23 +810,6 @@ class BaseSharesTest(test.BaseTestCase):
             cls.method_resources.insert(0, resource)
         return security_service
 
-    @classmethod
-    def create_share_type(cls, name, is_public=True, client=None,
-                          cleanup_in_class=True, **kwargs):
-        if client is None:
-            client = cls.shares_v2_client
-        share_type = client.create_share_type(name, is_public, **kwargs)
-        resource = {
-            "type": "share_type",
-            "id": share_type["share_type"]["id"],
-            "client": client,
-        }
-        if cleanup_in_class:
-            cls.class_resources.insert(0, resource)
-        else:
-            cls.method_resources.insert(0, resource)
-        return share_type
-
     @classmethod
     def update_share_type(cls, share_type_id, name=None,
                           is_public=None, description=None,
@@ -847,7 +826,7 @@ class BaseSharesTest(test.BaseTestCase):
         client = client or cls.shares_v2_client
         updated_quotas = client.update_quotas(project_id,
                                               user_id=user_id,
-                                              **kwargs)
+                                              **kwargs)['quota_set']
         resource = {
             "type": "quotas",
             "id": project_id,
@@ -858,37 +837,11 @@ class BaseSharesTest(test.BaseTestCase):
             cls.method_resources.insert(0, resource)
         return updated_quotas
 
-    @staticmethod
-    def add_extra_specs_to_dict(extra_specs=None):
-        """Add any required extra-specs to share type dictionary"""
-        dhss = six.text_type(CONF.share.multitenancy_enabled)
-        snapshot_support = six.text_type(
-            CONF.share.capability_snapshot_support)
-        create_from_snapshot_support = six.text_type(
-            CONF.share.capability_create_share_from_snapshot_support)
-
-        extra_specs_dict = {
-            "driver_handles_share_servers": dhss,
-        }
-
-        optional = {
-            "snapshot_support": snapshot_support,
-            "create_share_from_snapshot_support": create_from_snapshot_support,
-        }
-        # NOTE(gouthamr): In micro-versions < 2.24, snapshot_support is a
-        # required extra-spec
-        extra_specs_dict.update(optional)
-
-        if extra_specs:
-            extra_specs_dict.update(extra_specs)
-
-        return extra_specs_dict
-
     @classmethod
     def clear_share_replicas(cls, share_id, client=None):
         client = client or cls.shares_v2_client
         share_replicas = client.list_share_replicas(
-            share_id=share_id)
+            share_id=share_id)['share_replicas']
 
         for replica in share_replicas:
             try:
@@ -1082,10 +1035,11 @@ class BaseSharesTest(test.BaseTestCase):
 
         params = {'share_type_id': bogus_type['id'],
                   'share_network_id': self.shares_v2_client.share_network_id}
-        share = self.shares_v2_client.create_share(**params)
+        share = self.shares_v2_client.create_share(**params)['share']
         self.addCleanup(self.shares_v2_client.delete_share, share['id'])
-        self.shares_v2_client.wait_for_share_status(share['id'], "error")
-        return self.shares_v2_client.wait_for_message(share['id'])
+        waiters.wait_for_resource_status(
+            self.shares_v2_client, share['id'], "error")
+        return waiters.wait_for_message(self.shares_v2_client, share['id'])
 
     def allow_access(self, share_id, client=None, access_type=None,
                      access_level='rw', access_to=None, status='active',
@@ -1097,9 +1051,11 @@ class BaseSharesTest(test.BaseTestCase):
         access_to = access_to or a_to
 
         rule = client.create_access_rule(share_id, access_type, access_to,
-                                         access_level)
-        client.wait_for_access_rule_status(share_id, rule['id'], status,
-                                           raise_rule_in_error_state)
+                                         access_level)['access']
+        waiters.wait_for_resource_status(
+            client, share_id, status, resource_name='access_rule',
+            rule_id=rule['id'],
+            raise_rule_in_error_state=raise_rule_in_error_state)
         if cleanup:
             self.addCleanup(client.wait_for_resource_deletion,
                             rule_id=rule['id'], share_id=share_id)
@@ -1107,11 +1063,6 @@ class BaseSharesTest(test.BaseTestCase):
         return rule
 
 
-class BaseSharesAltTest(BaseSharesTest):
-    """Base test case class for all Shares Alt API tests."""
-    credentials = ('alt', )
-
-
 class BaseSharesAdminTest(BaseSharesTest):
     """Base test case class for all Shares Admin API tests."""
     credentials = ('admin', )
@@ -1120,15 +1071,40 @@ class BaseSharesAdminTest(BaseSharesTest):
     def setup_clients(cls):
         super(BaseSharesAdminTest, cls).setup_clients()
         # Initialise share clients
+        cls.admin_shares_client = cls.os_admin.share_v1.SharesClient()
         cls.admin_shares_v2_client = cls.os_admin.share_v2.SharesV2Client()
 
+    @staticmethod
+    def add_extra_specs_to_dict(extra_specs=None):
+        """Add any required extra-specs to share type dictionary"""
+        dhss = six.text_type(CONF.share.multitenancy_enabled)
+        extra_specs_dict = {"driver_handles_share_servers": dhss}
+        if extra_specs:
+            extra_specs_dict.update(extra_specs)
+        if CONF.share.capability_thin_provisioned:
+            extra_specs_dict['thin_provisioning'] = 'True'
+        return extra_specs_dict
+
     @classmethod
-    def _create_share_type(cls, is_public=True, specs=None):
-        name = data_utils.rand_name("unique_st_name")
-        extra_specs = cls.add_extra_specs_to_dict(specs)
-        return cls.create_share_type(
-            name, extra_specs=extra_specs, is_public=is_public,
-            client=cls.admin_shares_v2_client)['share_type']
+    def create_share_type(cls, name=None, is_public=True, client=None,
+                          cleanup_in_class=True, extra_specs=None, **kwargs):
+        name = name or data_utils.rand_name(
+            cls.__class__.__name__ + 'share-type')
+        client = client or cls.admin_shares_v2_client
+        extra_specs = cls.add_extra_specs_to_dict(extra_specs=extra_specs)
+        share_type = client.create_share_type(name, is_public,
+                                              extra_specs=extra_specs,
+                                              **kwargs)['share_type']
+        resource = {
+            "type": "share_type",
+            "id": share_type["id"],
+            "client": client,
+        }
+        if cleanup_in_class:
+            cls.class_resources.insert(0, resource)
+        else:
+            cls.method_resources.insert(0, resource)
+        return share_type
 
     @classmethod
     def _create_share_group_type(cls):
@@ -1139,15 +1115,16 @@ class BaseSharesAdminTest(BaseSharesTest):
 
     def _create_share_for_manage(self):
         creation_data = {
-            'share_type_id': self.st['share_type']['id'],
+            'share_type_id': self.st['id'],
             'share_protocol': self.protocol,
         }
 
         share = self.create_share(**creation_data)
-        share = self.shares_v2_client.get_share(share['id'])
+        share = self.shares_v2_client.get_share(share['id'])['share']
 
         if utils.is_microversion_ge(CONF.share.max_api_microversion, "2.9"):
-            el = self.shares_v2_client.list_share_export_locations(share["id"])
+            el = self.shares_v2_client.list_share_export_locations(
+                share["id"])['export_locations']
             share["export_locations"] = el
 
         return share
@@ -1181,13 +1158,14 @@ class BaseSharesAdminTest(BaseSharesTest):
             service_host=share['host'],
             export_path=share['export_locations'][0],
             protocol=share['share_proto'],
-            share_type_id=self.share_type['share_type']['id'],
+            share_type_id=self.share_type['id'],
             name=name,
             description=description,
             share_server_id=share_server_id
-        )
-        self.shares_v2_client.wait_for_share_status(
-            managed_share['id'], constants.STATUS_AVAILABLE
+        )['share']
+        waiters.wait_for_resource_status(
+            self.shares_v2_client, managed_share['id'],
+            constants.STATUS_AVAILABLE
         )
 
         return managed_share
@@ -1206,10 +1184,10 @@ class BaseSharesAdminTest(BaseSharesTest):
             params.get('share_network_id', share_server['share_network_id']),
             params.get('identifier', share_server['identifier']),
             share_network_subnet_id=subnet_id,
-        )
-        self.shares_v2_client.wait_for_share_server_status(
-            managed_share_server['id'],
-            constants.SERVER_STATE_ACTIVE,
+        )['share_server']
+        waiters.wait_for_resource_status(
+            self.shares_v2_client, managed_share_server['id'],
+            constants.SERVER_STATE_ACTIVE, resource_name='share_server'
         )
 
         return managed_share_server
@@ -1221,9 +1199,40 @@ class BaseSharesAdminTest(BaseSharesTest):
         self.shares_v2_client.wait_for_resource_deletion(
             server_id=share_server_id)
 
+    def create_user_message(self):
+        """Trigger a 'no valid host' situation to generate a message."""
+        extra_specs = {
+            'vendor_name': 'foobar',
+            'driver_handles_share_servers': CONF.share.multitenancy_enabled,
+        }
+        share_type_name = data_utils.rand_name("share-type")
 
-class BaseSharesMixedTest(BaseSharesTest):
-    """Base test case class for all Shares API tests with all user roles."""
+        bogus_type = self.create_share_type(
+            client=self.admin_shares_v2_client,
+            name=share_type_name,
+            extra_specs=extra_specs)
+
+        params = {'share_type_id': bogus_type['id'],
+                  'share_network_id': self.shares_v2_client.share_network_id}
+        share = self.shares_v2_client.create_share(**params)['share']
+        self.addCleanup(self.shares_v2_client.delete_share, share['id'])
+        waiters.wait_for_resource_status(
+            self.shares_v2_client, share['id'], "error")
+        return waiters.wait_for_message(self.shares_v2_client, share['id'])
+
+
+class BaseSharesMixedTest(BaseSharesAdminTest):
+    """Base test case class for all Shares API tests with all user roles.
+
+       Tests deriving from this class can use the primary project's clients
+       (self.shares_client, self.shares_v2_client) and the alt project user's
+       clients (self.alt_shares_client, self.alt_shares_v2_client) to perform
+       API calls and validations. Although admin clients are available for use,
+       their use should be limited to performing bootstrapping (e.g., creating
+       a share type, or resetting state of a resource, etc.). No API validation
+       must be performed against admin APIs. Use BaseAdminTest as a base class
+       for such tests.
+    """
     credentials = ('primary', 'alt', 'admin')
 
     # Will be cleaned up in resource_cleanup if the class
@@ -1244,9 +1253,6 @@ class BaseSharesMixedTest(BaseSharesTest):
     @classmethod
     def setup_clients(cls):
         super(BaseSharesMixedTest, cls).setup_clients()
-        # Initialise share clients
-        cls.admin_shares_client = cls.os_admin.share_v1.SharesClient()
-        cls.admin_shares_v2_client = cls.os_admin.share_v2.SharesV2Client()
         cls.alt_shares_client = cls.os_alt.share_v1.SharesClient()
         cls.alt_shares_v2_client = cls.os_alt.share_v2.SharesV2Client()
         # Initialise network clients
@@ -1263,7 +1269,8 @@ class BaseSharesMixedTest(BaseSharesTest):
         cls.os_admin.domains_client = (
             cls.os_admin.identity_v3.DomainsClient() if
             CONF.identity.auth_version == 'v3' else None)
-        cls.admin_project_member_client = cls.create_user_and_get_client()
+        cls.admin_project_member_client = cls.create_user_and_get_client(
+            project=cls.admin_project, add_member_role=True)
 
         if CONF.share.multitenancy_enabled:
             admin_share_network_id = cls.provide_share_network(
@@ -1278,7 +1285,7 @@ class BaseSharesMixedTest(BaseSharesTest):
             cls.alt_shares_v2_client.share_network_id = alt_share_network_id
 
     @classmethod
-    def create_user_and_get_client(cls, project=None):
+    def create_user_and_get_client(cls, project=None, add_member_role=True):
         """Create a user in specified project & set share clients for user
 
         The user will have all roles specified in tempest.conf
@@ -1303,9 +1310,12 @@ class BaseSharesMixedTest(BaseSharesTest):
             username, password, project, email)
         cls.class_project_users_created.append(user)
 
-        for conf_role in CONF.auth.tempest_roles:
-            cls.os_admin.creds_client.assign_user_role(
-                user, project, conf_role)
+        tempest_roles_to_assign = CONF.auth.tempest_roles or []
+        if "member" not in tempest_roles_to_assign and add_member_role:
+            tempest_roles_to_assign.append("member")
+
+        for role in tempest_roles_to_assign:
+            cls.os_admin.creds_client.assign_user_role(user, project, role)
 
         user_creds = cls.os_admin.creds_client.get_credentials(
             user, project, password)
@@ -1313,18 +1323,3 @@ class BaseSharesMixedTest(BaseSharesTest):
         os.shares_v1_client = os.share_v1.SharesClient()
         os.shares_v2_client = os.share_v2.SharesV2Client()
         return os
-
-    @classmethod
-    def _create_share_type(cls, is_public=True, specs=None):
-        name = data_utils.rand_name("unique_st_name")
-        extra_specs = cls.add_extra_specs_to_dict(specs)
-        return cls.create_share_type(
-            name, extra_specs=extra_specs, is_public=is_public,
-            client=cls.admin_shares_v2_client)['share_type']
-
-    @classmethod
-    def _create_share_group_type(cls):
-        share_group_type_name = data_utils.rand_name("unique_sgtype_name")
-        return cls.create_share_group_type(
-            name=share_group_type_name, share_types=[cls.share_type_id],
-            client=cls.admin_shares_v2_client)
