@@ -33,14 +33,15 @@ class SecServicesMappingNegativeTest(base.BaseSharesMixedTest):
     @classmethod
     def resource_setup(cls):
         super(SecServicesMappingNegativeTest, cls).resource_setup()
-        cls.sn = cls.create_share_network(cleanup_in_class=True)
+        cls.sn = cls.create_share_network(cleanup_in_class=True,
+                                          add_security_services=False)
         cls.share_net_info = (
             utils.share_network_get_default_subnet(cls.sn)
             if utils.share_network_subnets_are_supported() else cls.sn)
         cls.ss = cls.create_security_service(cleanup_in_class=True)
         cls.cl = cls.shares_client
         # create share type
-        cls.share_type = cls._create_share_type()
+        cls.share_type = cls.create_share_type()
         cls.share_type_id = cls.share_type['id']
 
     @decorators.idempotent_id('e3d17444-8ed4-445e-bc65-c748dbc5d21f')
@@ -113,8 +114,9 @@ class SecServicesMappingNegativeTest(base.BaseSharesMixedTest):
         not CONF.share.multitenancy_enabled, "Only for multitenancy.")
     def test_delete_ss_from_sn_used_by_share_server(self):
         sn = self.shares_client.get_share_network(
-            self.shares_client.share_network_id)
+            self.shares_client.share_network_id)['share_network']
         fresh_sn = self.create_share_network(
+            add_security_services=False,
             neutron_net_id=sn["neutron_net_id"],
             neutron_subnet_id=sn["neutron_subnet_id"])
 
@@ -147,7 +149,8 @@ class SecServicesMappingNegativeTest(base.BaseSharesMixedTest):
         # create share network
         data = self.generate_share_network_data()
 
-        sn = self.create_share_network(client=self.cl, **data)
+        sn = self.create_share_network(client=self.cl,
+                                       add_security_services=False, **data)
         self.assertDictContainsSubset(data, sn)
 
         # create security services with same type
@@ -173,7 +176,8 @@ class SecServicesMappingNegativeTest(base.BaseSharesMixedTest):
         # create share network
         data = self.generate_share_network_data()
 
-        sn = self.create_share_network(client=self.cl, **data)
+        sn = self.create_share_network(client=self.cl,
+                                       add_security_services=False, **data)
         self.assertDictContainsSubset(data, sn)
 
         # create security service
