@@ -33,7 +33,7 @@ class SecurityServicesNegativeTest(base.BaseSharesMixedTest):
     def resource_setup(cls):
         super(SecurityServicesNegativeTest, cls).resource_setup()
         # create share_type
-        cls.share_type = cls._create_share_type()
+        cls.share_type = cls.create_share_type()
         cls.share_type_id = cls.share_type['id']
 
     @decorators.idempotent_id('f5cdf074-f5d4-4d9e-990b-c3d9385dfc2b')
@@ -98,8 +98,9 @@ class SecurityServicesNegativeTest(base.BaseSharesMixedTest):
         ss = self.create_security_service(**ss_data)
 
         sn = self.shares_client.get_share_network(
-            self.shares_client.share_network_id)
+            self.shares_client.share_network_id)['share_network']
         fresh_sn = self.create_share_network(
+            add_security_services=False,
             neutron_net_id=sn["neutron_net_id"],
             neutron_subnet_id=sn["neutron_subnet_id"])
 
