@@ -34,7 +34,7 @@ class ShareTypeAvailabilityZonesTest(base.BaseSharesMixedTest):
     @classmethod
     def resource_setup(cls):
         super(ShareTypeAvailabilityZonesTest, cls).resource_setup()
-        cls.share_type = cls._create_share_type()
+        cls.share_type = cls.create_share_type()
         cls.share_type_id = cls.share_type['id']
         cls.share_group_type = cls._create_share_group_type()
         cls.share_group_type_id = cls.share_group_type['id']
@@ -57,7 +57,7 @@ class ShareTypeAvailabilityZonesTest(base.BaseSharesMixedTest):
             data_utils.rand_name('az_share_type'),
             cleanup_in_class=False,
             extra_specs=extra_specs,
-            client=self.admin_shares_v2_client)['share_type']
+            client=self.admin_shares_v2_client)
         self.assertEqual(
             'az1,az2,az 3', share_type['extra_specs']['availability_zones'])
 
@@ -77,14 +77,14 @@ class ShareTypeAvailabilityZonesTest(base.BaseSharesMixedTest):
             data_utils.rand_name('support_some_azs_share_type'),
             cleanup_in_class=False,
             extra_specs=extra_specs,
-            client=self.admin_shares_v2_client)['share_type']
+            client=self.admin_shares_v2_client)
 
         extra_specs = self.add_extra_specs_to_dict()
         share_type_no_az_spec = self.create_share_type(
             data_utils.rand_name('support_any_az_share_type'),
             cleanup_in_class=False,
             extra_specs=extra_specs,
-            client=self.admin_shares_v2_client)['share_type']
+            client=self.admin_shares_v2_client)
 
         share_types = self.admin_shares_v2_client.list_share_types(
             params={'extra_specs': {'availability_zones': filter}}
@@ -108,7 +108,7 @@ class ShareTypeAvailabilityZonesTest(base.BaseSharesMixedTest):
             self.share_type_id, self.az_spec, self.invalid_azs_spec)
         share = self.create_share(share_type_id=self.share_type_id,
                                   cleanup_in_class=False, version='2.47')
-        share = self.shares_v2_client.get_share(share['id'])
+        share = self.shares_v2_client.get_share(share['id'])['share']
         # Test default scheduler behavior: the share type capabilities should
         # have ensured the share landed in an AZ that is supported
         # regardless of the 'availability_zones' extra-spec
@@ -126,7 +126,7 @@ class ShareTypeAvailabilityZonesTest(base.BaseSharesMixedTest):
             'availability_zone': self.valid_azs[0] if specify_az else None,
         }
         share = self.create_share(**kwargs)
-        share = self.shares_v2_client.get_share(share['id'])
+        share = self.shares_v2_client.get_share(share['id'])['share']
         if specify_az:
             self.assertEqual(self.valid_azs[0], share['availability_zone'])
         else:
@@ -146,7 +146,8 @@ class ShareTypeAvailabilityZonesTest(base.BaseSharesMixedTest):
         }
         # Create share group
         share_group = self.create_share_group(**kwargs)
-        share_group = self.shares_v2_client.get_share_group(share_group['id'])
+        share_group = self.shares_v2_client.get_share_group(
+            share_group['id'])['share_group']
         if specify_az:
             self.assertEqual(self.valid_azs[0],
                              share_group['availability_zone'])
