@@ -26,6 +26,7 @@ from tempest.lib import exceptions
 
 from manila_tempest_tests.common import constants
 from manila_tempest_tests.common import remote_client
+from manila_tempest_tests.common import waiters as share_waiters
 from manila_tempest_tests.tests.api import base
 from manila_tempest_tests.tests.scenario import manager
 from manila_tempest_tests import utils
@@ -197,7 +198,6 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
         # NOTE(u_glide): Workaround for bug #1465682
         remote_client = remote_client.ssh_client
 
-        self.share = self.shares_client.get_share(self.share['id'])
         return remote_client
 
     def validate_ping_to_export_location(self, export, remote_client,
@@ -267,17 +267,18 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
     def migration_complete(self, share_id, dest_host):
         return self._migration_complete(share_id, dest_host)
 
-    def create_share(self, **kwargs):
+    def create_share(self, extra_specs=None, **kwargs):
         kwargs.update({
             'share_protocol': self.protocol,
         })
         if not ('share_type_id' in kwargs or 'snapshot_id' in kwargs):
-            default_share_type_id = self.get_share_type()['id']
+            default_share_type_id = self.get_share_type(
+                extra_specs=extra_specs)['id']
             kwargs.update({'share_type_id': default_share_type_id})
         if CONF.share.multitenancy_enabled:
             kwargs.update({'share_network_id': self.share_network['id']})
-        self.share = self._create_share(**kwargs)
-        return self.share
+        share = self._create_share(**kwargs)
+        return share
 
     def get_remote_client(self, *args, **kwargs):
         if not CONF.share.image_with_share_tools:
@@ -347,13 +348,14 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
         """
         client = client or self.shares_client
         client.delete_access_rule(share_id, access_rule_id)
-        self.shares_v2_client.wait_for_share_status(
-            share_id, "active", status_attr='access_rules_status')
+        share_waiters.wait_for_resource_status(
+            self.shares_v2_client, share_id, "active",
+            status_attr='access_rules_status')
 
-    def provide_access_to_auxiliary_instance(self, instance, share=None,
-                                             snapshot=None, access_level='rw',
-                                             client=None):
-        share = share or self.share
+    def _provide_access_to_client_identified_by_ip(self, instance, share=None,
+                                                   snapshot=None,
+                                                   access_level='rw',
+                                                   client=None):
         client = client or self.shares_v2_client
         if not CONF.share.multitenancy_enabled:
             if self.ipv6_enabled and not self.storage_network:
@@ -375,42 +377,63 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
                 share['id'], instance=instance, cleanup=False,
                 snapshot=snapshot, access_level=access_level, client=client)
 
-    def provide_access_to_client_identified_by_cephx(self, share=None,
-                                                     access_level='rw',
-                                                     access_to=None,
-                                                     remote_client=None,
-                                                     locations=None,
-                                                     client=None,
-                                                     oc_size=20971520):
-        share = share or self.share
-        client = client or self.shares_v2_client
-        access_to = access_to or data_utils.rand_name(
-            self.__class__.__name__ + '-cephx-id')
-        # Check if access is already granted to the client
-        access = self.shares_v2_client.list_access_rules(
-            share['id'], metadata={'metadata': {'access_to': access_to}})
-        access = access[0] if access else None
+    def _provide_access_to_client_identified_by_cephx(self, share=None,
+                                                      access_rule=None,
+                                                      access_level='rw',
+                                                      access_to=None,
+                                                      remote_client=None,
+                                                      locations=None,
+                                                      client=None,
+                                                      oc_size=20971520):
+        """Provide an access to a client identified by cephx authentication
 
-        if not access:
-            access = self._allow_access(
-                share['id'], access_level=access_level, access_to=access_to,
-                access_type="cephx", cleanup=False, client=client)
-            # Set metadata to access rule to be filtered if necessary.
-            # This is necessary to prevent granting access to a client who
-            # already has.
-            self.shares_v2_client.update_access_metadata(
-                metadata={"access_to": "{}".format(access_to)},
-                access_id=access['id'])
-        get_access = self.shares_v2_client.get_access(access['id'])
+        :param: share: An existing share.
+        :param: access_rule: An existing access rule. In case we want to create
+                        the configuration files in the instance according to an
+                        existing access rule.
+        :param: access_level: Share access level; this is not required if
+                        "access_rule" is set.
+        :param: access_to: Client to provide access to; this is not required if
+                        "access_rule" is set.
+        :param: remote_client: An SSH client connection to the Nova instance.
+        :param: locations: Export locations of shares.
+        :param: client: Client object.
+        :param: oc_size: Set how many bytes of data will the client cache.
+        :return: Share access.
+
+        """
+        client = client or self.shares_v2_client
+        if not access_rule:
+            access_to = access_to or data_utils.rand_name(
+                self.__class__.__name__ + '-cephx-id')
+            # Check if access is already granted to the client
+            access_rules_matching_client = client.list_access_rules(
+                share['id'],
+                metadata={'metadata': {'access_to': access_to}})['access_list']
+            access_rule = (access_rules_matching_client[0] if
+                           access_rules_matching_client else None)
+
+            if not access_rule:
+                access_rule = self._allow_access(
+                    share['id'], access_level=access_level,
+                    access_to=access_to, access_type="cephx", cleanup=False,
+                    client=client)
+                # Set metadata to access rule to be filtered if necessary.
+                # This is necessary to prevent granting access to a client who
+                # already has.
+                client.update_access_metadata(
+                    metadata={"access_to": "{}".format(access_to)},
+                    access_id=access_rule['id'])
+        get_access = client.get_access_rule(access_rule['id'])['access']
         # Set 'access_key' and 'access_to' attributes for being use in mount
         # operation.
         setattr(self, 'access_key', get_access['access_key'])
-        setattr(self, 'access_to', access_to)
+        setattr(self, 'access_to', get_access['access_to'])
 
         remote_client.exec_command(
             "sudo crudini --set {access_to}.keyring client.{access_to} key "
             "{access_key}"
-            .format(access_to=access_to, access_key=self.access_key))
+            .format(access_to=self.access_to, access_key=self.access_key))
         remote_client.exec_command(
             "sudo crudini --set ceph.conf client \"client quota\" true")
         remote_client.exec_command(
@@ -421,7 +444,7 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
         remote_client.exec_command(
             "sudo crudini --set ceph.conf client \"mon host\" {}"
             .format(locations[0].split(':/')[0]))
-        return access
+        return access_rule
 
     def wait_for_active_instance(self, instance_id):
         waiters.wait_for_server_status(
@@ -429,29 +452,30 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
         return self.os_primary.servers_client.show_server(
             instance_id)["server"]
 
-    def get_share_type(self):
+    def get_share_type(self, extra_specs=None):
         if CONF.share.default_share_type_name:
-            return self.shares_client.get_share_type(
-                CONF.share.default_share_type_name)['share_type']
+            return self.shares_client.get_default_share_type()['share_type']
+        extra_specs_dict = {
+            'driver_handles_share_servers': CONF.share.multitenancy_enabled
+        }
+        if extra_specs:
+            extra_specs_dict.update(extra_specs)
         return self._create_share_type(
             data_utils.rand_name("share_type"),
-            extra_specs={
-                'snapshot_support': CONF.share.capability_snapshot_support,
-                'driver_handles_share_servers': CONF.share.multitenancy_enabled
-            },)['share_type']
+            extra_specs=extra_specs_dict)['share_type']
 
     def get_share_export_locations(self, share):
         if utils.is_microversion_lt(CONF.share.max_api_microversion, "2.9"):
             locations = share['export_locations']
         else:
             exports = self.shares_v2_client.list_share_export_locations(
-                share['id'])
+                share['id'])['export_locations']
             locations = [x['path'] for x in exports]
         return locations
 
     def _get_snapshot_export_locations(self, snapshot):
-        exports = (self.shares_v2_client.
-                   list_snapshot_export_locations(snapshot['id']))
+        exports = (self.shares_v2_client.list_snapshot_export_locations(
+            snapshot['id'])['share_snapshot_export_locations'])
         locations = [x['path'] for x in exports]
 
         return locations
@@ -503,7 +527,7 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
             'share_network_id': share_network_id,
             'share_type_id': share_type_id,
         }
-        share = self.shares_client.create_share(**kwargs)
+        share = self.shares_client.create_share(**kwargs)['share']
 
         if cleanup:
             self.addCleanup(client.wait_for_resource_deletion,
@@ -511,16 +535,18 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
             self.addCleanup(client.delete_share,
                             share['id'])
 
-        client.wait_for_share_status(share['id'], 'available')
+        share_waiters.wait_for_resource_status(client, share['id'],
+                                               'available')
         return share
 
     def _create_snapshot(self, share_id, client=None, **kwargs):
         client = client or self.shares_v2_client
-        snapshot = client.create_snapshot(share_id, **kwargs)
+        snapshot = client.create_snapshot(share_id, **kwargs)['snapshot']
         self.addCleanup(
             client.wait_for_resource_deletion, snapshot_id=snapshot['id'])
         self.addCleanup(client.delete_snapshot, snapshot['id'])
-        client.wait_for_snapshot_status(snapshot["id"], "available")
+        share_waiters.wait_for_resource_status(
+            client, snapshot["id"], "available", resource_name='snapshot')
         return snapshot
 
     def _wait_for_share_server_deletion(self, sn_id, client=None):
@@ -531,7 +557,7 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
         """
         client = client or self.shares_admin_client
         servers = client.list_share_servers(
-            search_opts={"share_network": sn_id})
+            search_opts={"share_network": sn_id})['share_servers']
         for server in servers:
             client.delete_share_server(server['id'])
         for server in servers:
@@ -545,7 +571,7 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
         """
 
         client = client or self.shares_client
-        sn = client.create_share_network(**kwargs)
+        sn = client.create_share_network(**kwargs)['share_network']
 
         self.addCleanup(client.wait_for_resource_deletion,
                         sn_id=sn['id'])
@@ -568,10 +594,10 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
         """
         client = client or self.shares_v2_client
         access = client.create_access_rule(share_id, access_type, access_to,
-                                           access_level)
+                                           access_level)['access']
 
-        client.wait_for_share_status(
-            share_id, "active", status_attr='access_rules_status')
+        share_waiters.wait_for_resource_status(
+            client, share_id, "active", status_attr='access_rules_status')
 
         if cleanup:
             self.addCleanup(client.delete_access_rule, share_id, access['id'])
@@ -590,14 +616,16 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
         """
         client = client or self.shares_v2_client
         access = client.create_snapshot_access_rule(
-            snapshot_id, access_type, access_to)
+            snapshot_id, access_type, access_to)['snapshot_access']
 
         if cleanup:
             self.addCleanup(client.delete_snapshot_access_rule,
                             snapshot_id, access['id'])
 
-        client.wait_for_snapshot_access_rule_status(
-            snapshot_id, access['id'])
+        share_waiters.wait_for_resource_status(
+            client, snapshot_id, 'active',
+            resource_name='snapshot_access', rule_id=access['id'],
+            status_attr='state')
 
         return access
 
@@ -622,15 +650,16 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
             share_id, dest_host, writable=False, preserve_metadata=False,
             nondisruptive=False, preserve_snapshots=False,
             force_host_assisted_migration=force_host_assisted)
-        share = client.wait_for_migration_status(share_id, dest_host, status)
+        share = share_waiters.wait_for_migration_status(
+            client, share_id, dest_host, status)
         return share
 
     def _migration_complete(self, share_id, dest_host, client=None, **kwargs):
         client = client or self.shares_admin_v2_client
         client.migration_complete(share_id, **kwargs)
-        share = client.wait_for_migration_status(
-            share_id, dest_host, constants.TASK_STATE_MIGRATION_SUCCESS,
-            **kwargs)
+        share = share_waiters.wait_for_migration_status(
+            client, share_id, dest_host,
+            constants.TASK_STATE_MIGRATION_SUCCESS, **kwargs)
         return share
 
     def _create_share_type(self, name, is_public=True, **kwargs):
@@ -701,12 +730,73 @@ class ShareScenarioTest(manager.NetworkScenarioTest):
         return ip, version
 
 
-class BaseShareCEPHFSTest(ShareScenarioTest):
+class BaseShareScenarioNFSTest(ShareScenarioTest):
+    protocol = "nfs"
+
+    @classmethod
+    def skip_checks(cls):
+        super(BaseShareScenarioNFSTest, cls).skip_checks()
+        if cls.protocol not in CONF.share.enable_ip_rules_for_protocols:
+            message = ("%s tests for access rules other than IP are disabled" %
+                       cls.protocol)
+            raise cls.skipException(message)
 
     def allow_access(self, access_level='rw', **kwargs):
-        return self.provide_access_to_client_identified_by_cephx(
-            remote_client=kwargs['remote_client'],
-            locations=kwargs['locations'], access_level=access_level)
+        snapshot = kwargs.get('snapshot')
+        share = kwargs.get('share')
+        return self._provide_access_to_client_identified_by_ip(
+            share=share, instance=kwargs['instance'],
+            access_level=access_level, snapshot=snapshot)
+
+    def mount_share(self, location, ssh_client, target_dir=None):
+
+        self.validate_ping_to_export_location(location, ssh_client)
+
+        target_dir = target_dir or "/mnt"
+        ssh_client.exec_command(
+            "sudo mount -vt nfs \"%s\" %s" % (location, target_dir)
+        )
+
+
+class BaseShareScenarioCIFSTest(ShareScenarioTest):
+    protocol = 'cifs'
+
+    @classmethod
+    def skip_checks(cls):
+        super(BaseShareScenarioCIFSTest, cls).skip_checks()
+        if cls.protocol not in CONF.share.enable_ip_rules_for_protocols:
+            message = ("%s tests for access rules other than IP are disabled" %
+                       cls.protocol)
+            raise cls.skipException(message)
+
+    def allow_access(self, access_level='rw', **kwargs):
+        share = kwargs.get('share')
+        snapshot = kwargs.get('snapshot')
+        return self._provide_access_to_client_identified_by_ip(
+            instance=kwargs['instance'],
+            share=share,
+            snapshot=snapshot,
+            access_level=access_level)
+
+    def mount_share(self, location, ssh_client, target_dir=None):
+
+        self.validate_ping_to_export_location(location, ssh_client)
+
+        location = location.replace("\\", "/")
+        target_dir = target_dir or "/mnt"
+        ssh_client.exec_command(
+            "sudo mount.cifs \"%s\" %s -o guest" % (location, target_dir)
+        )
+
+
+class BaseShareScenarioCEPHFSTest(ShareScenarioTest):
+    protocol = 'cephfs'
+
+    def allow_access(self, access_level='rw', access_rule=None, **kwargs):
+        return self._provide_access_to_client_identified_by_cephx(
+            share=kwargs['share'], remote_client=kwargs['remote_client'],
+            locations=kwargs['locations'], access_level=access_level,
+            access_rule=access_rule)
 
     def _fuse_client(self, mountpoint, remote_client, target_dir, access_to):
         remote_client.exec_command(
@@ -734,4 +824,5 @@ class BaseShareCEPHFSTest(ShareScenarioTest):
         if getattr(self, 'mount_client', None):
             return remote_client.exec_command(
                 "sudo fusermount -uz %s" % target_dir)
-        super(BaseShareCEPHFSTest, self).unmount_share(remote_client)
+        super(BaseShareScenarioCEPHFSTest, self).unmount_share(
+            remote_client, target_dir=target_dir)
